<?php
$active_tab = $_GET['tab'] ?? 'checker';

function get_header($title) {
    return <<<HTML
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>$title</title>
        <script src="https://cdn.tailwindcss.com"></script>
        <script src="https://unpkg.com/lucide@latest"></script>
        <script defer src="js/main.js"></script>
    </head>
    <body class="min-h-screen bg-gradient-to-br from-slate-900 to-slate-800 text-white">
HTML;
}

function get_footer() {
    $year = date('Y');
    return <<<HTML
        <footer class="bg-slate-900 border-t border-slate-800 py-6">
            <div class="container mx-auto px-4 text-center text-slate-400">
                <p>© $year WeakPasswords.com - Stay Safe Online</p>
            </div>
        </footer>
    </body>
    </html>
HTML;
}

echo get_header('WeakPasswords.com - Password Security Tools');
?>

<!-- Header -->
<header class="bg-slate-800/50 backdrop-blur-sm border-b border-slate-700">
    <div class="container mx-auto px-4 py-6">
        <div class="flex items-center gap-3">
            <i data-lucide="shield" class="w-8 h-8 text-emerald-400"></i>
            <h1 class="text-2xl font-bold">WeakPasswords.com</h1>
        </div>
        <p class="mt-2 text-slate-400">Your guide to better password security</p>
    </div>
</header>

<!-- Navigation -->
<nav class="bg-slate-800/30 border-b border-slate-700">
    <div class="container mx-auto px-4">
        <div class="flex space-x-1">
            <a href="?tab=checker" 
               class="px-4 py-3 flex items-center gap-2 transition <?php echo $active_tab === 'checker' ? 'text-emerald-400 border-b-2 border-emerald-400' : 'text-slate-400 hover:text-white'; ?>">
                <i data-lucide="alert-triangle" class="w-4 h-4"></i>
                Password Checker
            </a>
            <a href="?tab=generator" 
               class="px-4 py-3 flex items-center gap-2 transition <?php echo $active_tab === 'generator' ? 'text-emerald-400 border-b-2 border-emerald-400' : 'text-slate-400 hover:text-white'; ?>">
                <i data-lucide="key" class="w-4 h-4"></i>
                Password Generator
            </a>
            <a href="?tab=quiz" 
               class="px-4 py-3 flex items-center gap-2 transition <?php echo $active_tab === 'quiz' ? 'text-emerald-400 border-b-2 border-emerald-400' : 'text-slate-400 hover:text-white'; ?>">
                <i data-lucide="brain" class="w-4 h-4"></i>
                Security Quiz
            </a>
            <a href="?tab=tools" 
               class="px-4 py-3 flex items-center gap-2 transition <?php echo $active_tab === 'tools' ? 'text-emerald-400 border-b-2 border-emerald-400' : 'text-slate-400 hover:text-white'; ?>">
                <i data-lucide="shield-check" class="w-4 h-4"></i>
                Security Tools
            </a>
        </div>
    </div>
</nav>

<!-- Main Content -->
<main class="container mx-auto px-4 py-8">
    <?php
    switch($active_tab) {
        case 'checker':
            include 'pages/password-checker.php';
            break;
        case 'generator':
            include 'pages/password-generator.php';
            break;
        case 'quiz':
            include 'pages/security-quiz.php';
            break;
        case 'tools':
            include 'pages/security-tools.php';
            break;
    }
    ?>
</main>

<?php echo get_footer(); ?>