// Initialize Lucide icons
lucide.createIcons();

// Password Checker
const passwordInput = document.getElementById('password-input');
const strengthText = document.getElementById('strength-text');
const strengthBar = document.getElementById('strength-bar');
const requirementsList = document.getElementById('requirements-list');
const passwordStrength = document.getElementById('password-strength');

if (passwordInput) {
    passwordInput.addEventListener('input', function() {
        const password = this.value;
        let score = 0;
        
        if (password.length >= 8) score++;
        if (password.length >= 12) score++;
        if (/[A-Z]/.test(password)) score++;
        if (/[a-z]/.test(password)) score++;
        if (/[0-9]/.test(password)) score++;
        if (/[^A-Za-z0-9]/.test(password)) score++;

        const requirements = [
            { test: password.length >= 8, text: 'At least 8 characters' },
            { test: /[A-Z]/.test(password), text: 'Contains uppercase letters' },
            { test: /[a-z]/.test(password), text: 'Contains lowercase letters' },
            { test: /[0-9]/.test(password), text: 'Contains numbers' },
            { test: /[^A-Za-z0-9]/.test(password), text: 'Contains special characters' }
        ];

        requirementsList.innerHTML = requirements.map(req => `
            <li class="flex items-center gap-2 ${req.test ? 'text-green-400' : 'text-slate-400'}">
                <i data-lucide="${req.test ? 'check-circle-2' : 'info'}" class="w-4 h-4"></i>
                ${req.text}
            </li>
        `).join('');

        lucide.createIcons();

        const strength = score <= 2 ? 'Weak' : score <= 4 ? 'Moderate' : 'Strong';
        const color = score <= 2 ? 'bg-red-500' : score <= 4 ? 'bg-yellow-500' : 'bg-green-500';
        
        strengthText.textContent = strength;
        strengthText.className = `text-lg font-semibold ${score <= 2 ? 'text-red-500' : score <= 4 ? 'text-yellow-500' : 'text-green-500'}`;
        strengthBar.className = `h-full rounded-full transition-all ${color}`;
        strengthBar.style.width = `${(score / 6) * 100}%`;
        
        passwordStrength.classList.remove('hidden');
    });
}

// Password Generator
const generateBtn = document.getElementById('generate-btn');
const copyBtn = document.getElementById('copy-btn');
const lengthRange = document.getElementById('length-range');
const lengthValue = document.getElementById('length-value');
const passwordOutput = document.getElementById('password-output');
const generatedPassword = document.getElementById('generated-password');

if (generateBtn) {
    lengthRange.addEventListener('input', function() {
        lengthValue.textContent = this.value;
    });

    generateBtn.addEventListener('click', function() {
        const length = parseInt(lengthRange.value);
        const useUppercase = document.getElementById('uppercase').checked;
        const useLowercase = document.getElementById('lowercase').checked;
        const useNumbers = document.getElementById('numbers').checked;
        const useSpecial = document.getElementById('special').checked;

        let chars = '';
        if (useUppercase) chars += 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
        if (useLowercase) chars += 'abcdefghijklmnopqrstuvwxyz';
        if (useNumbers) chars += '0123456789';
        if (useSpecial) chars += '!@#$%^&*()_+-=[]{}|;:,.<>?';

        if (!chars) {
            alert('Please select at least one character type');
            return;
        }

        let password = '';
        for (let i = 0; i < length; i++) {
            const randomIndex = Math.floor(Math.random() * chars.length);
            password += chars[randomIndex];
        }

        generatedPassword.value = password;
        passwordOutput.classList.remove('hidden');
    });

    copyBtn.addEventListener('click', function() {
        generatedPassword.select();
        document.execCommand('copy');
        alert('Password copied to clipboard!');
    });
}