import React, { useState } from 'react';
import { Shield, Key, BrainCircuit, ChevronRight, AlertTriangle, CheckCircle2, ShieldCheck } from 'lucide-react';
import PasswordChecker from './components/PasswordChecker';
import PasswordGenerator from './components/PasswordGenerator';
import SecurityQuiz from './components/SecurityQuiz';
import SecurityTools from './components/SecurityTools';

function App() {
  const [activeTab, setActiveTab] = useState('checker');

  return (
    <div className="min-h-screen bg-gradient-to-br from-slate-900 to-slate-800 text-white">
      {/* Header */}
      <header className="bg-slate-800/50 backdrop-blur-sm border-b border-slate-700">
        <div className="container mx-auto px-4 py-6">
          <div className="flex items-center gap-3">
            <Shield className="w-8 h-8 text-emerald-400" />
            <h1 className="text-2xl font-bold">WeakPasswords.com</h1>
          </div>
          <p className="mt-2 text-slate-400">Your guide to better password security</p>
        </div>
      </header>

      {/* Navigation */}
      <nav className="bg-slate-800/30 border-b border-slate-700">
        <div className="container mx-auto px-4">
          <div className="flex space-x-1">
            <button
              onClick={() => setActiveTab('checker')}
              className={`px-4 py-3 flex items-center gap-2 transition ${
                activeTab === 'checker'
                  ? 'text-emerald-400 border-b-2 border-emerald-400'
                  : 'text-slate-400 hover:text-white'
              }`}
            >
              <AlertTriangle className="w-4 h-4" />
              Password Checker
            </button>
            <button
              onClick={() => setActiveTab('generator')}
              className={`px-4 py-3 flex items-center gap-2 transition ${
                activeTab === 'generator'
                  ? 'text-emerald-400 border-b-2 border-emerald-400'
                  : 'text-slate-400 hover:text-white'
              }`}
            >
              <Key className="w-4 h-4" />
              Password Generator
            </button>
            <button
              onClick={() => setActiveTab('quiz')}
              className={`px-4 py-3 flex items-center gap-2 transition ${
                activeTab === 'quiz'
                  ? 'text-emerald-400 border-b-2 border-emerald-400'
                  : 'text-slate-400 hover:text-white'
              }`}
            >
              <BrainCircuit className="w-4 h-4" />
              Security Quiz
            </button>
            <button
              onClick={() => setActiveTab('tools')}
              className={`px-4 py-3 flex items-center gap-2 transition ${
                activeTab === 'tools'
                  ? 'text-emerald-400 border-b-2 border-emerald-400'
                  : 'text-slate-400 hover:text-white'
              }`}
            >
              <ShieldCheck className="w-4 h-4" />
              Security Tools
            </button>
          </div>
        </div>
      </nav>

      {/* Main Content */}
      <main className="container mx-auto px-4 py-8">
        {activeTab === 'checker' && <PasswordChecker />}
        {activeTab === 'generator' && <PasswordGenerator />}
        {activeTab === 'quiz' && <SecurityQuiz />}
        {activeTab === 'tools' && <SecurityTools />}
      </main>

      {/* Footer */}
      <footer className="bg-slate-900 border-t border-slate-800 py-6">
        <div className="container mx-auto px-4 text-center text-slate-400">
          <p>© {new Date().getFullYear()} WeakPasswords.com - Stay Safe Online</p>
        </div>
      </footer>
    </div>
  );
}

export default App;