import React, { useState } from 'react';
import { AlertTriangle, CheckCircle2, Info } from 'lucide-react';

export default function PasswordChecker() {
  const [password, setPassword] = useState('');

  const checkStrength = (pass: string) => {
    let score = 0;
    if (pass.length >= 8) score++;
    if (pass.length >= 12) score++;
    if (/[A-Z]/.test(pass)) score++;
    if (/[a-z]/.test(pass)) score++;
    if (/[0-9]/.test(pass)) score++;
    if (/[^A-Za-z0-9]/.test(pass)) score++;
    return score;
  };

  const getStrengthColor = (score: number) => {
    if (score <= 2) return 'text-red-500';
    if (score <= 4) return 'text-yellow-500';
    return 'text-green-500';
  };

  const getStrengthText = (score: number) => {
    if (score <= 2) return 'Weak';
    if (score <= 4) return 'Moderate';
    return 'Strong';
  };

  const score = checkStrength(password);

  return (
    <div className="max-w-2xl mx-auto">
      <div className="bg-slate-800/50 rounded-lg p-6 shadow-xl">
        <h2 className="text-xl font-bold mb-4 flex items-center gap-2">
          <AlertTriangle className="text-yellow-500" />
          Password Strength Checker
        </h2>
        
        <div className="space-y-4">
          <div>
            <label className="block text-sm font-medium text-slate-300 mb-1">
              Enter your password to check its strength
            </label>
            <input
              type="password"
              value={password}
              onChange={(e) => setPassword(e.target.value)}
              className="w-full px-4 py-2 bg-slate-700 rounded border border-slate-600 focus:border-emerald-400 focus:ring-1 focus:ring-emerald-400 outline-none transition"
              placeholder="Enter password..."
            />
          </div>

          {password && (
            <div className="space-y-4">
              <div className="flex items-center gap-2">
                <span className={`text-lg font-semibold ${getStrengthColor(score)}`}>
                  {getStrengthText(score)}
                </span>
                <div className="flex-1 h-2 bg-slate-700 rounded-full">
                  <div
                    className={`h-full rounded-full transition-all ${
                      score <= 2
                        ? 'bg-red-500'
                        : score <= 4
                        ? 'bg-yellow-500'
                        : 'bg-green-500'
                    }`}
                    style={{ width: `${(score / 6) * 100}%` }}
                  />
                </div>
              </div>

              <div className="space-y-2">
                <h3 className="font-medium text-slate-300">Password Requirements:</h3>
                <ul className="space-y-1">
                  <li className={`flex items-center gap-2 ${password.length >= 8 ? 'text-green-400' : 'text-slate-400'}`}>
                    {password.length >= 8 ? <CheckCircle2 className="w-4 h-4" /> : <Info className="w-4 h-4" />}
                    At least 8 characters
                  </li>
                  <li className={`flex items-center gap-2 ${/[A-Z]/.test(password) ? 'text-green-400' : 'text-slate-400'}`}>
                    {/[A-Z]/.test(password) ? <CheckCircle2 className="w-4 h-4" /> : <Info className="w-4 h-4" />}
                    Contains uppercase letters
                  </li>
                  <li className={`flex items-center gap-2 ${/[a-z]/.test(password) ? 'text-green-400' : 'text-slate-400'}`}>
                    {/[a-z]/.test(password) ? <CheckCircle2 className="w-4 h-4" /> : <Info className="w-4 h-4" />}
                    Contains lowercase letters
                  </li>
                  <li className={`flex items-center gap-2 ${/[0-9]/.test(password) ? 'text-green-400' : 'text-slate-400'}`}>
                    {/[0-9]/.test(password) ? <CheckCircle2 className="w-4 h-4" /> : <Info className="w-4 h-4" />}
                    Contains numbers
                  </li>
                  <li className={`flex items-center gap-2 ${/[^A-Za-z0-9]/.test(password) ? 'text-green-400' : 'text-slate-400'}`}>
                    {/[^A-Za-z0-9]/.test(password) ? <CheckCircle2 className="w-4 h-4" /> : <Info className="w-4 h-4" />}
                    Contains special characters
                  </li>
                </ul>
              </div>
            </div>
          )}
        </div>
      </div>
    </div>
  );
}