import React, { useState } from 'react';
import { Key, Copy, RefreshCw } from 'lucide-react';

export default function PasswordGenerator() {
  const [length, setLength] = useState(16);
  const [useUppercase, setUseUppercase] = useState(true);
  const [useLowercase, setUseLowercase] = useState(true);
  const [useNumbers, setUseNumbers] = useState(true);
  const [useSpecial, setUseSpecial] = useState(true);
  const [generatedPassword, setGeneratedPassword] = useState('');

  const generatePassword = () => {
    const uppercase = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
    const lowercase = 'abcdefghijklmnopqrstuvwxyz';
    const numbers = '0123456789';
    const special = '!@#$%^&*()_+-=[]{}|;:,.<>?';

    let chars = '';
    if (useUppercase) chars += uppercase;
    if (useLowercase) chars += lowercase;
    if (useNumbers) chars += numbers;
    if (useSpecial) chars += special;

    if (!chars) {
      setGeneratedPassword('Please select at least one character type');
      return;
    }

    let password = '';
    for (let i = 0; i < length; i++) {
      const randomIndex = Math.floor(Math.random() * chars.length);
      password += chars[randomIndex];
    }
    setGeneratedPassword(password);
  };

  const copyToClipboard = () => {
    navigator.clipboard.writeText(generatedPassword);
  };

  return (
    <div className="max-w-2xl mx-auto">
      <div className="bg-slate-800/50 rounded-lg p-6 shadow-xl">
        <h2 className="text-xl font-bold mb-4 flex items-center gap-2">
          <Key className="text-emerald-400" />
          Password Generator
        </h2>

        <div className="space-y-6">
          <div>
            <label className="block text-sm font-medium text-slate-300 mb-2">
              Password Length: {length}
            </label>
            <input
              type="range"
              min="8"
              max="32"
              value={length}
              onChange={(e) => setLength(parseInt(e.target.value))}
              className="w-full h-2 bg-slate-700 rounded-lg appearance-none cursor-pointer"
            />
          </div>

          <div className="space-y-3">
            <div className="flex items-center">
              <input
                type="checkbox"
                id="uppercase"
                checked={useUppercase}
                onChange={(e) => setUseUppercase(e.target.checked)}
                className="w-4 h-4 text-emerald-400 bg-slate-700 border-slate-600 rounded focus:ring-emerald-400"
              />
              <label htmlFor="uppercase" className="ml-2 text-sm text-slate-300">
                Include Uppercase Letters
              </label>
            </div>
            <div className="flex items-center">
              <input
                type="checkbox"
                id="lowercase"
                checked={useLowercase}
                onChange={(e) => setUseLowercase(e.target.checked)}
                className="w-4 h-4 text-emerald-400 bg-slate-700 border-slate-600 rounded focus:ring-emerald-400"
              />
              <label htmlFor="lowercase" className="ml-2 text-sm text-slate-300">
                Include Lowercase Letters
              </label>
            </div>
            <div className="flex items-center">
              <input
                type="checkbox"
                id="numbers"
                checked={useNumbers}
                onChange={(e) => setUseNumbers(e.target.checked)}
                className="w-4 h-4 text-emerald-400 bg-slate-700 border-slate-600 rounded focus:ring-emerald-400"
              />
              <label htmlFor="numbers" className="ml-2 text-sm text-slate-300">
                Include Numbers
              </label>
            </div>
            <div className="flex items-center">
              <input
                type="checkbox"
                id="special"
                checked={useSpecial}
                onChange={(e) => setUseSpecial(e.target.checked)}
                className="w-4 h-4 text-emerald-400 bg-slate-700 border-slate-600 rounded focus:ring-emerald-400"
              />
              <label htmlFor="special" className="ml-2 text-sm text-slate-300">
                Include Special Characters
              </label>
            </div>
          </div>

          <button
            onClick={generatePassword}
            className="w-full py-2 px-4 bg-emerald-500 hover:bg-emerald-600 text-white rounded-lg transition flex items-center justify-center gap-2"
          >
            <RefreshCw className="w-4 h-4" />
            Generate Password
          </button>

          {generatedPassword && (
            <div className="mt-4">
              <div className="flex items-center gap-2">
                <input
                  type="text"
                  value={generatedPassword}
                  readOnly
                  className="w-full px-4 py-2 bg-slate-700 rounded-lg border border-slate-600"
                />
                <button
                  onClick={copyToClipboard}
                  className="p-2 bg-slate-700 hover:bg-slate-600 rounded-lg transition"
                  title="Copy to clipboard"
                >
                  <Copy className="w-5 h-5" />
                </button>
              </div>
            </div>
          )}
        </div>
      </div>
    </div>
  );
}