import React from 'react';
import { Shield, Lock, Wifi, ShieldCheck, ExternalLink } from 'lucide-react';

const tools = [
  {
    category: 'Password Managers',
    icon: Lock,
    items: [
      {
        name: 'LastPass',
        description: 'Secure password manager with cross-platform support',
        url: 'https://www.lastpass.com',
        price: 'Free & Premium plans',
      },
      {
        name: '1Password',
        description: 'Feature-rich password manager for individuals and families',
        url: 'https://1password.com',
        price: 'Paid subscription',
      },
      {
        name: 'Bitwarden',
        description: 'Open-source password manager with strong encryption',
        url: 'https://bitwarden.com',
        price: 'Free & Premium plans',
      },
    ],
  },
  {
    category: 'VPN Services',
    icon: Wifi,
    items: [
      {
        name: 'NordVPN',
        description: 'High-speed VPN with advanced security features',
        url: 'https://nordvpn.com',
        price: 'Subscription-based',
      },
      {
        name: 'ExpressVPN',
        description: 'Premium VPN service with servers in 94 countries',
        url: 'https://expressvpn.com',
        price: 'Subscription-based',
      },
      {
        name: 'ProtonVPN',
        description: 'Secure VPN from the creators of ProtonMail',
        url: 'https://protonvpn.com',
        price: 'Free & Premium plans',
      },
    ],
  },
  {
    category: 'Antivirus Software',
    icon: ShieldCheck,
    items: [
      {
        name: 'Bitdefender',
        description: 'Advanced protection against malware and cyber threats',
        url: 'https://www.bitdefender.com',
        price: 'Free & Premium versions',
      },
      {
        name: 'Malwarebytes',
        description: 'Specialized anti-malware and internet security',
        url: 'https://www.malwarebytes.com',
        price: 'Free & Premium versions',
      },
      {
        name: 'Kaspersky',
        description: 'Comprehensive security suite for all devices',
        url: 'https://www.kaspersky.com',
        price: 'Paid subscription',
      },
    ],
  },
];

export default function SecurityTools() {
  return (
    <div className="max-w-4xl mx-auto">
      <div className="bg-slate-800/50 rounded-lg p-6 shadow-xl">
        <h2 className="text-xl font-bold mb-6 flex items-center gap-2">
          <Shield className="text-blue-400" />
          Recommended Security Tools
        </h2>

        <div className="space-y-8">
          {tools.map((category) => (
            <div key={category.category}>
              <h3 className="text-lg font-semibold mb-4 flex items-center gap-2">
                <category.icon className="w-5 h-5 text-blue-400" />
                {category.category}
              </h3>
              
              <div className="grid grid-cols-1 md:grid-cols-3 gap-4">
                {category.items.map((tool) => (
                  <a
                    key={tool.name}
                    href={tool.url}
                    target="_blank"
                    rel="noopener noreferrer"
                    className="block bg-slate-700/50 rounded-lg p-4 hover:bg-slate-700 transition group"
                  >
                    <div className="flex justify-between items-start mb-2">
                      <h4 className="font-medium text-blue-400 group-hover:text-blue-300">
                        {tool.name}
                      </h4>
                      <ExternalLink className="w-4 h-4 text-slate-400 group-hover:text-blue-400" />
                    </div>
                    <p className="text-sm text-slate-300 mb-2">{tool.description}</p>
                    <p className="text-xs text-slate-400">{tool.price}</p>
                  </a>
                ))}
              </div>
            </div>
          ))}
        </div>

        <div className="mt-8 p-4 bg-slate-700/30 rounded-lg">
          <p className="text-sm text-slate-300">
            <strong className="text-blue-400">Note:</strong> These are recommended tools based on popularity and features. Always research and compare options to find the best fit for your needs. Some tools offer free trials or money-back guarantees.
          </p>
        </div>
      </div>
    </div>
  );
}